%%TYPE number
%%BEGIN

0xC4,0x4
0xC5,0x4
0xC6,0x4
0xC7,0x4
0x1F54,0x4
0x1F55,0x4
0x1F56,0x4
0x1F57,0x4
0x1F58,0x4
0x14E7,0x6
0x1F59,0x4
0x1F5A,0x4
0x1F5B,0x4
0x1F5C,0x4
0x1F5D,0x4
0x20E,0x4
0x16D,0x4
0x1F5E,0x4
0x1F5F,0x4
0x1F60,0x4
0x1F61,0x4
0x1F62,0x4
0x1177,0x6
0x1F63,0x4
0x1F64,0x4
0x1F65,0x4
0x1F66,0x4
0x1F67,0x4
0x1598,0x6
0x21B,0x4
0x2008,0x4
0x2009,0x4
0x1F68,0x4
0x200A,0x4
0x200B,0x4
0x1F69,0x4
0x200C,0x4
0x1F6A,0x4
0x1F6B,0x4
0x200D,0x4
0x200E,0x4
0x1F6C,0x4
0x200F,0x4
0x1F6D,0x4
0x159F,0x6
0x1F6E,0x4
0x2010,0x4
0x1879,0x6
0x1F6F,0x4
0x2011,0x4
0x1F70,0x4
0x1F71,0x4
0x7B7,0x6
0xE0C,0x6
0x21C,0x4
0x21D,0x4
0x21E,0x4
0x21F,0x4
0x220,0x4
0x221,0x4
0x222,0x4
0x2012,0x4
0x2013,0x4
0x2014,0x4
0x1F72,0x4
0x2015,0x4
0x1F73,0x4
0x1F74,0x4
0x2016,0x4
0x2017,0x4
0x1F75,0x4
0x2018,0x4
0x1F76,0x4
0x1506,0x6
0x1F77,0x4
0x2019,0x4
0x1F78,0x4
0x201A,0x4
0x201B,0x4
0x1F79,0x4
0x1F7A,0x4
0x1F7B,0x4
0xB3C,0x6
0x201C,0x4
0x201D,0x4
0x1F7C,0x4
0x201E,0x4
0x201F,0x4
0x1F7D,0x4
0x2020,0x4
0x1F7F,0x4
0x2021,0x4
0x2022,0x4
0x1F80,0x4
0x1F81,0x4
0x2023,0x4
0x2024,0x4
0x1F82,0x4
0x2025,0x4
0x1F83,0x4
0x1F84,0x4
0xEBF,0x6
0x1F85,0x4
0x2D8,0x4
0x2D9,0x4
0x2026,0x4
0x2027,0x4
0x2028,0x4
0x1F86,0x4
0x1F87,0x4
0x2029,0x4
0x1F88,0x4
0x202A,0x4
0x202B,0x4
0x1F89,0x4
0x202C,0x4
0x1F8A,0x4
0x1F8B,0x4
0x202D,0x4
0x202E,0x4
0x1D55,0x6
0x202F,0x4
0x1F8D,0x4
0x1F8E,0x4
0x1F8F,0x4
0x2DA,0x4
0x2DB,0x4
0x2DC,0x4
0x2DE,0x4
0x2DF,0x4
0x2E0,0x4
0x2E1,0x4
0x2E2,0x4
0x2E3,0x4
0x20D0,0x4
0x20D2,0x4
0x2030,0x4
0x20D3,0x4
0x2031,0x4
0x20D4,0x4
0x2032,0x4
0x1F90,0x4
0x1F91,0x4
0x20D5,0x4
0x2033,0x4
0x2034,0x4
0x1F92,0x4
0x20D6,0x4
0x20D7,0x4
0x2035,0x4
0x1F93,0x4
0x1F94,0x4
0x20D8,0x4
0x2036,0x4
0x2037,0x4
0x1F95,0x4
0x20D9,0x4
0x2038,0x4
0x1F96,0x4
0x1F97,0x4
0x2039,0x4
0x384,0x4
0x1F99,0x4
0x385,0x4
0x386,0x4
0x2E4,0x4
0x2E5,0x4
0x387,0x4
0x388,0x4
0x2E6,0x4
0x389,0x4
0x2E7,0x4
0x38A,0x4
0x2E8,0x4
0x38B,0x4
0x2E9,0x4
0x38C,0x4
0x2EA,0x4
0x2EB,0x4
0x38D,0x4
0x2EC,0x4
0x2ED,0x4
0x20DA,0x4
0x20DB,0x4
0x20DC,0x4
0x203A,0x4
0x203B,0x4
0x20DD,0x4
0x20DE,0x4
0x203C,0x4
0x1F9A,0x4
0x1F9B,0x4
0x20DF,0x4
0x203D,0x4
0x203E,0x4
0x1F9C,0x4
0x20E0,0x4
0x203F,0x4
0x20E1,0x4
0x1F9D,0x4
0x1F9E,0x4
0x20E2,0x4
0x2040,0x4
0x1F9F,0x4
0x20E3,0x4
0x2041,0x4
0x1FA0,0x4
0x2042,0x4
0x1FA1,0x4
0x2043,0x4
0x1FA2,0x4
0x1FA3,0x4
0x38E,0x4
0x38F,0x4
0x390,0x4
0x391,0x4
0x392,0x4
0x2F0,0x4
0x393,0x4
0x2F1,0x4
0x394,0x4
0x2F2,0x4
0x2F3,0x4
0x395,0x4
0x2F4,0x4
0x396,0x4
0x2F5,0x4
0x397,0x4
0x2F6,0x4
0x2F7,0x4
0x20E4,0x4
0x2044,0x4
0x20E6,0x4
0x2045,0x4
0x20E7,0x4
0x20E8,0x4
0x2046,0x4
0x2047,0x4
0x12FD,0x6
0x20E9,0x4
0x20EA,0x4
0x2048,0x4
0x20EB,0x4
0x2049,0x4
0x20EC,0x4
0x204A,0x4
0x204B,0x4
0x20ED,0x4
0x204C,0x4
0x167E,0x6
0x204D,0x4
0x398,0x4
0x399,0x4
0x39A,0x4
0x2F8,0x4
0x2F9,0x4
0x39B,0x4
0x39C,0x4
0x2FA,0x4
0x39D,0x4
0x2FB,0x4
0x3E8,0x4
0x2FC,0x4
0x39E,0x4
0x2FD,0x4
0x39F,0x4
0x3E9,0x4
0x3EA,0x4
0x3A0,0x4
0x2FE,0x4
0x3EB,0x4
0x3A1,0x4
0x2FF,0x4
0x300,0x4
0x3EC,0x4
0x3ED,0x4
0x301,0x4
0x3EE,0x4
0x3EF,0x4
0x20EE,0x4
0x20EF,0x4
0x204E,0x4
0x20F0,0x4
0x20F1,0x4
0x204F,0x4
0x20F2,0x4
0x2050,0x4
0x20F3,0x4
0x2051,0x4
0x20F4,0x4
0x2052,0x4
0x20F5,0x4
0x2053,0x4
0x2054,0x4
0x20F6,0x4
0x20F7,0x4
0x2055,0x4
0x2057,0x4
0x3A2,0x4
0x3A3,0x4
0x3A4,0x4
0x302,0x4
0x303,0x4
0x3A5,0x4
0x304,0x4
0x3A6,0x4
0x3A7,0x4
0x305,0x4
0x306,0x4
0x3A8,0x4
0x3F2,0x4
0x3A9,0x4
0x3F3,0x4
0x307,0x4
0x3F4,0x4
0x308,0x4
0x3AA,0x4
0x309,0x4
0x3F5,0x4
0x3AB,0x4
0x3F6,0x4
0x30A,0x4
0x30B,0x4
0x3F7,0x4
0x3F8,0x4
0x3F9,0x4
0x3FA,0x4
0x3FB,0x4
0x2198,0x4
0x2199,0x4
0x20F8,0x4
0x219A,0x4
0x219B,0x4
0x20F9,0x4
0x219C,0x4
0x20FA,0x4
0x2058,0x4
0x20FB,0x4
0x219D,0x4
0x2059,0x4
0x20FC,0x4
0x205A,0x4
0x219E,0x4
0x205B,0x4
0x219F,0x4
0x1AA9,0x6
0xF96,0x6
0x20FD,0x4
0x21A0,0x4
0x20FE,0x4
0x205C,0x4
0x21A1,0x4
0x20FF,0x4
0x205D,0x4
0x2100,0x4
0x205E,0x4
0x2101,0x4
0x205F,0x4
0x2060,0x4
0x2061,0x4
0x3AC,0x4
0x3AD,0x4
0x30C,0x4
0x3AE,0x4
0x3AF,0x4
0x30D,0x4
0x3B0,0x4
0x30E,0x4
0x30F,0x4
0x3B1,0x4
0x3FC,0x4
0x3B2,0x4
0x310,0x4
0x3B3,0x4
0x311,0x4
0x3FD,0x4
0x312,0x4
0x3FE,0x4
0x3B4,0x4
0x3FF,0x4
0x3B5,0x4
0x313,0x4
0x400,0x4
0x314,0x4
0x401,0x4
0x315,0x4
0x402,0x4
0x403,0x4
0x404,0x4
0x405,0x4
0x21A3,0x4
0x21A4,0x4
0x2102,0x4
0x2103,0x4
0x21A5,0x4
0x21A6,0x4
0x2104,0x4
0x21A7,0x4
0x2105,0x4
0x2064,0x4
0x2106,0x4
0x21A8,0x4
0x21A9,0x4
0x2065,0x4
0x2107,0x4
0x2108,0x4
0x21AA,0x4
0x2109,0x4
0x21AB,0x4
0x210A,0x4
0x210B,0x4
0x2069,0x4
0x206B,0x4
0x3B6,0x4
0x3B7,0x4
0x3B8,0x4
0x316,0x4
0x317,0x4
0x3B9,0x4
0x3BA,0x4
0x318,0x4
0x3BB,0x4
0x319,0x4
0x31A,0x4
0x406,0x4
0x3BC,0x4
0x3BD,0x4
0x31B,0x4
0x407,0x4
0x3BE,0x4
0x408,0x4
0x31C,0x4
0x409,0x4
0x31D,0x4
0x3BF,0x4
0x31E,0x4
0x40A,0x4
0x31F,0x4
0x40B,0x4
0x40C,0x4
0x40D,0x4
0x40E,0x4
0x40F,0x4
0x21AC,0x4
0x21AD,0x4
0x210C,0x4
0x21AE,0x4
0x21AF,0x4
0x210D,0x4
0x21B0,0x4
0x210E,0x4
0x210F,0x4
0x21B1,0x4
0x2110,0x4
0x21B2,0x4
0x2111,0x4
0x21B3,0x4
0x21B4,0x4
0x2113,0x4
0x21B5,0x4
0x2114,0x4
0x2115,0x4
0x3C0,0x4
0x3C1,0x4
0x3C2,0x4
0x3C3,0x4
0x3C4,0x4
0x4B0,0x4
0x3C5,0x4
0x4B1,0x4
0x4B2,0x4
0x3C6,0x4
0x410,0x4
0x4B3,0x4
0x411,0x4
0x3C7,0x4
0x412,0x4
0x3C8,0x4
0x4B4,0x4
0x3C9,0x4
0x4B5,0x4
0x413,0x4
0x4B6,0x4
0x1EDC,0x4
0x21B6,0x4
0x1EDD,0x4
0x1EDE,0x4
0x21B7,0x4
0x2116,0x4
0x21B8,0x4
0x21B9,0x4
0x2117,0x4
0x1EE0,0x4
0x2118,0x4
0x1EE1,0x4
0x21BA,0x4
0x2119,0x4
0x21BB,0x4
0x211A,0x4
0x1EE3,0x4
0x21BC,0x4
0x1EE4,0x4
0x21BD,0x4
0x211B,0x4
0x211C,0x4
0x1EE5,0x4
0x21BE,0x4
0x21BF,0x4
0x211D,0x4
0x211E,0x4
0x211F,0x4
0x3CA,0x4
0x3CB,0x4
0x3CC,0x4
0x3CD,0x4
0x3CE,0x4
0x4BA,0x4
0x3D0,0x4
0x3D1,0x4
0x3D2,0x4
0x4BF,0x4
0x41E,0x4
0x4C0,0x4
0x41F,0x4
0x420,0x4
0x421,0x4
0x422,0x4
0x423,0x4
0x2260,0x4
0x2261,0x4
0x1EE6,0x4
0x21C0,0x4
0x1EE7,0x4
0x2262,0x4
0x21C1,0x4
0x1EE8,0x4
0x2263,0x4
0x2120,0x4
0x2264,0x4
0x21C2,0x4
0x1EE9,0x4
0x21C3,0x4
0x2121,0x4
0x2265,0x4
0x1EEA,0x4
0x1EEB,0x4
0x21C4,0x4
0x2122,0x4
0x2266,0x4
0x2123,0x4
0x2267,0x4
0x1EEC,0x4
0x21C5,0x4
0x21C6,0x4
0x2124,0x4
0x2268,0x4
0x1EED,0x4
0x2269,0x4
0x1EEE,0x4
0x2125,0x4
0x21C7,0x4
0x1AD1,0x6
0x2126,0x4
0x1EEF,0x4
0x21C8,0x4
0x21C9,0x4
0x2127,0x4
0x2128,0x4
0x2129,0x4
0x4C4,0x4
0x4C5,0x4
0x424,0x4
0x841,0x6
0x3DB,0x4
0x425,0x4
0x4C7,0x4
0x426,0x4
0x4C8,0x4
0x3DC,0x4
0x3DD,0x4
0x4C9,0x4
0x427,0x4
0x845,0x6
0x4CA,0x4
0x428,0x4
0x429,0x4
0x4CB,0x4
0x42A,0x4
0x4CC,0x4
0x42B,0x4
0x4CD,0x4
0x42C,0x4
0x42D,0x4
0x226A,0x4
0x226B,0x4
0x1EF0,0x4
0x21CA,0x4
0x226C,0x4
0x1EF1,0x4
0x226D,0x4
0x1EF2,0x4
0x21CB,0x4
0x212A,0x4
0x226E,0x4
0x1EF3,0x4
0x21CC,0x4
0x1EF4,0x4
0x21CD,0x4
0x212B,0x4
0x226F,0x4
0x212C,0x4
0x1EF5,0x4
0x21CE,0x4
0x2270,0x4
0x21CF,0x4
0x2271,0x4
0x212D,0x4
0x1EF6,0x4
0x21D0,0x4
0x1EF7,0x4
0x2272,0x4
0x212E,0x4
0x212F,0x4
0x21D1,0x4
0x1EF8,0x4
0x2273,0x4
0x2130,0x4
0x21D2,0x4
0x1EF9,0x4
0x21D3,0x4
0x2131,0x4
0x2132,0x4
0x2133,0x4
0x3DE,0x4
0x3DF,0x4
0x3E0,0x4
0x848,0x6
0x3E1,0x4
0x3E2,0x4
0x4CE,0x4
0x3E3,0x4
0x4CF,0x4
0x42E,0x4
0x3E4,0x4
0x4D0,0x4
0x3E5,0x4
0xBC7,0x6
0x4D1,0x4
0x42F,0x4
0x430,0x4
0x4D2,0x4
0x3E6,0x4
0x431,0x4
0x4D3,0x4
0x84E,0x6
0x3E7,0x4
0x432,0x4
0x4D4,0x4
0x4D5,0x4
0x433,0x4
0x434,0x4
0x4D6,0x4
0x435,0x4
0x4D7,0x4
0x436,0x4
0x437,0x4
0x2274,0x4
0x2275,0x4
0x1EFB,0x4
0x21D4,0x4
0x2276,0x4
0x2277,0x4
0x1EFC,0x4
0x21D5,0x4
0x21D6,0x4
0x2278,0x4
0x1EFD,0x4
0x1EFE,0x4
0x21D7,0x4
0x2279,0x4
0x1EFF,0x4
0x227A,0x4
0x21D8,0x4
0x1F00,0x4
0x227B,0x4
0x21D9,0x4
0x21DA,0x4
0x1F01,0x4
0x227C,0x4
0x227D,0x4
0x21DB,0x4
0x1F02,0x4
0x1F03,0x4
0x21DC,0x4
0x21DD,0x4
0x578,0x4
0x579,0x4
0x57A,0x4
0x4D8,0x4
0x4D9,0x4
0x57B,0x4
0x57C,0x4
0x4DA,0x4
0x438,0x4
0x57D,0x4
0x4DB,0x4
0x439,0x4
0x857,0x6
0x57E,0x4
0x4DC,0x4
0x43A,0x4
0x57F,0x4
0x43B,0x4
0x580,0x4
0x43C,0x4
0x4DE,0x4
0x4DF,0x4
0x43D,0x4
0x4E0,0x4
0x43E,0x4
0x4E1,0x4
0x43F,0x4
0x440,0x4
0x441,0x4
0x227E,0x4
0x1F04,0x4
0x21DE,0x4
0x1F05,0x4
0x1F06,0x4
0x21DF,0x4
0x21E0,0x4
0x1F07,0x4
0x1F08,0x4
0x21E1,0x4
0x1F09,0x4
0x21E2,0x4
0x21E3,0x4
0x1F0A,0x4
0x21E4,0x4
0x1F0B,0x4
0x1F0C,0x4
0x21E5,0x4
0x21E6,0x4
0x1F0D,0x4
0x21E7,0x4
0x583,0x6
0x4E2,0x4
0x4E3,0x4
0x442,0x4
0x4E4,0x4
0x4E5,0x4
0x443,0x4
0x444,0x4
0x4E6,0x4
0x445,0x4
0x4E7,0x4
0x4E8,0x4
0x446,0x4
0x447,0x4
0x4E9,0x4
0x4EA,0x4
0x448,0x4
0x449,0x4
0x4EB,0x4
0x44A,0x4
0x44B,0x4
0x1F0E,0x4
0x1F0F,0x4
0x21E8,0x4
0x1F10,0x4
0x21E9,0x4
0x21EA,0x4
0x1F11,0x4
0x21EB,0x4
0x1F12,0x4
0x1F13,0x4
0x21EC,0x4
0x21ED,0x4
0x1F14,0x4
0x21EE,0x4
0x1F15,0x4
0x1F16,0x4
0x21EF,0x4
0x1F17,0x4
0x21F0,0x4
0x21F1,0x4
0x4EC,0x4
0x4ED,0x4
0x90B,0x6
0x4EF,0x4
0x4F0,0x4
0x4F1,0x4
0x4F2,0x4
0x594,0x6
0x4F3,0x4
0x4F4,0x4
0x1F18,0x4
0x1F19,0x4
0x21F2,0x4
0x21F3,0x4
0x1F1A,0x4
0x21F4,0x4
0x1F1B,0x4
0x21F5,0x4
0x21F6,0x4
0x1F1D,0x4
0x21F7,0x4
0x1F1E,0x4
0x1F1F,0x4
0x21F8,0x4
0x1F20,0x4
0x21F9,0x4
0x21FA,0x4
0x1F21,0x4
0x21FB,0x4
0x4F6,0x4
0x4F7,0x4
0x4F8,0x4
0x4F9,0x4
0x4FA,0x4
0x4FB,0x4
0x4FC,0x4
0x4FD,0x4
0x4FE,0x4
0x4FF,0x4
0x1F22,0x4
0x1F23,0x4
0x1F24,0x4
0x1F25,0x4
0x1F26,0x4
0x1F27,0x4
0x1F28,0x4
0x1F29,0x4
0x1F2A,0x4
0x1F2B,0x4
0x91C,0x6
0xC98,0x6
0x500,0x4
0x501,0x4
0x502,0x4
0x646,0x6
0x647,0x6
0x503,0x4
0x504,0x4
0x505,0x4
0x506,0x4
0x507,0x4
0x509,0x4
0x1F2C,0x4
0x1F2D,0x4
0x1F2E,0x4
0x1F2F,0x4
0x1F30,0x4
0x1F31,0x4
0x1F32,0x4
0x1F33,0x4
0x1F34,0x4
0x1F35,0x4
0xBFE,0x6
0x50A,0x4
0x885,0x6
0x50B,0x4
0x50C,0x4
0x50E,0x4
0x50F,0x4
0x510,0x4
0x511,0x4
0x512,0x4
0x1F36,0x4
0x1F37,0x4
0x1F38,0x4
0x1F3A,0x4
0x1F3B,0x4
0x1F3C,0x4
0x1F3D,0x4
0x1F3E,0x4
0x1F3F,0x4
0x1022,0x6
0xC08,0x6
0xD4D,0x6
0xD56,0x6
0xC8,0x4
0xD6,0x4
0xDA,0x4
0xDB,0x4
0xD6E,0x6
0x71B,0x6
0x71C,0x6
0x1B68,0x6
0x10F9,0x6
0x72B,0x6
0x10FC,0x6
0xF6,0x4
0xF7,0x4
0xF8,0x4
0xF9,0x4
0xD85,0x6
0x1061,0x6
0xD8A,0x6
0xA11,0x6
0xA12,0x6
0xFA,0x4
0xFB,0x4
0xD8F,0x6
0xE3B,0x6
0x1118,0x4
0x1119,0x4
0xE40,0x6
0x111A,0x4
0x111B,0x4
0x117,0x4
0x1FA4,0x4
0x1FA5,0x4
0x1FA6,0x4
0x1FA7,0x4
0x11BC,0x6
0x1FA8,0x4
0x1FA9,0x4
0x1FAA,0x4
0x111C,0x4
0x111D,0x4
0x1FAB,0x4
0x111E,0x4
0x1FAC,0x4
0x1FAD,0x4
0x111F,0x4
0x1120,0x4
0x1121,0x4
0x1122,0x4
0x1123,0x4
0x1FAE,0x4
0x1FAF,0x4
0x1FB0,0x4
0x1C35,0x6
0x1FB1,0x4
0x1FB2,0x4
0x1FB3,0x4
0x1126,0x4
0x1FB4,0x4
0x1127,0x4
0x1FB5,0x4
0x18BF,0x6
0x1128,0x4
0x1FB6,0x4
0x1FB7,0x4
0x1129,0x4
0x112A,0x4
0x112B,0x4
0x112C,0x4
0x112D,0x4
0x112E,0x4
0xADA,0x6
0x112F,0x4
0x1FB8,0x4
0x1FB9,0x4
0x1FBA,0x4
0x1FBB,0x4
0x1FBC,0x4
0x1825,0x6
0x1FBD,0x4
0x1FBE,0x4
0x1827,0x6
0x1FBF,0x4
0x1FC0,0x4
0x1FC1,0x4
0xE5F,0x6
0xAE4,0x6
0x1FC2,0x4
0x1FC3,0x4
0x1FC4,0x4
0x1FC5,0x4
0x1FC6,0x4
0x1FC7,0x4
0xE61,0x6
0x1FC9,0x4
0x1FCA,0x4
0x1FCB,0x4
0x206C,0x4
0x206D,0x4
0x1FCC,0x4
0x1FCD,0x4
0x2070,0x4
0x1FCE,0x4
0x1FCF,0x4
0x2071,0x4
0x2072,0x4
0x1FD0,0x4
0x1FD1,0x4
0x2073,0x4
0x2074,0x4
0x1FD2,0x4
0x1BB6,0x6
0x2075,0x4
0x1FD3,0x4
0x1FD4,0x4
0x1FD5,0x4
0x320,0x4
0x321,0x4
0x322,0x4
0x323,0x4
0x324,0x4
0x325,0x4
0x326,0x4
0x285,0x4
0x327,0x4
0x286,0x4
0x328,0x4
0x287,0x4
0x329,0x4
0x288,0x4
0x289,0x4
0x2076,0x4
0x2077,0x4
0x1FD6,0x4
0x2078,0x4
0x1FD7,0x4
0x2079,0x4
0x1FD8,0x4
0x207A,0x4
0x1FD9,0x4
0x207B,0x4
0x1FDA,0x4
0x207D,0x4
0x1FDB,0x4
0x1FDC,0x4
0x207E,0x4
0x207F,0x4
0x1FDD,0x4
0x1FDE,0x4
0x1FDF,0x4
0x32A,0x4
0x32B,0x4
0x32C,0x4
0x28A,0x4
0x32D,0x4
0x28B,0x4
0x32E,0x4
0x28C,0x4
0x28D,0x4
0x32F,0x4
0x28E,0x4
0x330,0x4
0x28F,0x4
0x331,0x4
0x1EE,0x4
0x332,0x4
0x290,0x4
0x333,0x4
0x1EF,0x4
0x292,0x6
0x1F0,0x4
0x1F1,0x4
0x293,0x6
0x1F2,0x4
0x1F3,0x4
0x2081,0x4
0x1FE0,0x4
0x2082,0x4
0x2083,0x4
0x1FE1,0x4
0x1FE2,0x4
0x2084,0x4
0x1FE3,0x4
0x2085,0x4
0x2086,0x4
0x1FE4,0x4
0x1FE5,0x4
0x2087,0x4
0x2088,0x4
0x1FE6,0x4
0x2089,0x4
0xBA7,0x6
0x1FE7,0x4
0x16BA,0x6
0x1FE8,0x4
0x1FE9,0x4
0x334,0x4
0x335,0x4
0x294,0x6
0x336,0x4
0x337,0x4
0x295,0x6
0x338,0x4
0x296,0x6
0x297,0x6
0x339,0x4
0x33A,0x4
0x298,0x6
0x33B,0x4
0x299,0x6
0x33C,0x4
0x29A,0x6
0x29B,0x6
0x33D,0x4
0x29C,0x6
0x29D,0x6
0x208A,0x4
0x208B,0x4
0x208C,0x4
0x1FEA,0x4
0x208D,0x4
0x1FEB,0x4
0x1FEC,0x4
0x208E,0x4
0x208F,0x4
0x1FED,0x4
0x2090,0x4
0x1FEE,0x4
0x1FEF,0x4
0x2091,0x4
0x1FF0,0x4
0x2092,0x4
0x1FF1,0x4
0x1FF2,0x4
0x1FF3,0x4
0x33E,0x4
0x33F,0x4
0x29E,0x6
0x340,0x4
0x341,0x4
0x29F,0x6
0x2A0,0x6
0x342,0x4
0x2A1,0x6
0x343,0x4
0x2A2,0x6
0x344,0x4
0x2A3,0x6
0x345,0x4
0x2A4,0x6
0x346,0x4
0x347,0x4
0x2A5,0x6
0x2A6,0x6
0x2A7,0x6
0x2134,0x4
0x2135,0x4
0x2136,0x4
0x2094,0x4
0x2095,0x4
0x2137,0x4
0x2138,0x4
0x2096,0x4
0x1FF4,0x4
0x1FF5,0x4
0x2139,0x4
0x2097,0x4
0x213A,0x4
0x2098,0x4
0x2099,0x4
0x1FF7,0x4
0x213B,0x4
0x1FF8,0x4
0x209A,0x4
0x213C,0x4
0x213D,0x4
0x209B,0x4
0x1FF9,0x4
0x209C,0x4
0x1FFA,0x4
0x209D,0x4
0x1FFB,0x4
0x1FFC,0x4
0x1FFD,0x4
0x348,0x4
0x349,0x4
0x2A8,0x6
0x34A,0x4
0x34B,0x4
0x2A9,0x6
0x2AA,0x6
0x34C,0x4
0x2AB,0x6
0x34D,0x4
0x34E,0x4
0x2AC,0x6
0x2AD,0x6
0x34F,0x4
0x2AE,0x6
0x350,0x4
0x2AF,0x6
0x351,0x4
0x2B0,0x6
0x2B1,0x6
0x213E,0x4
0x213F,0x4
0x2140,0x4
0x209E,0x4
0x209F,0x4
0x2141,0x4
0x20A0,0x4
0x1FFE,0x4
0x2142,0x4
0x2143,0x4
0x1FFF,0x4
0x20A1,0x4
0x1D26,0x6
0x20A2,0x4
0x2000,0x4
0x2144,0x4
0x2145,0x4
0x2001,0x4
0x20A3,0x4
0x2146,0x4
0x2002,0x4
0x20A4,0x4
0x20A5,0x4
0x2003,0x4
0x2147,0x4
0x2004,0x4
0x20A6,0x4
0x2005,0x4
0x20A7,0x4
0x2006,0x4
0x2007,0x4
0x352,0x4
0x353,0x4
0x354,0x4
0x355,0x4
0x356,0x4
0x357,0x4
0x358,0x4
0x359,0x4
0x35A,0x4
0x35B,0x4
0x2148,0x4
0x2149,0x4
0x214A,0x4
0x20A8,0x4
0x20A9,0x4
0x214B,0x4
0x214C,0x4
0x20AA,0x4
0x214D,0x4
0x20AB,0x4
0x20AC,0x4
0x214E,0x4
0x214F,0x4
0x20AD,0x4
0x20AE,0x4
0x2150,0x4
0x20AF,0x4
0x2151,0x4
0x20B0,0x4
0x20B1,0x4
0x35C,0x4
0x35D,0x4
0x35E,0x4
0x35F,0x4
0x360,0x4
0x44C,0x4
0x44D,0x4
0x361,0x4
0x362,0x4
0x44E,0x4
0x44F,0x4
0x363,0x4
0x364,0x4
0x450,0x4
0x451,0x4
0x365,0x4
0x452,0x4
0x453,0x4
0x454,0x4
0x455,0x4
0x2152,0x4
0x2153,0x4
0x1E7A,0x6
0x20B2,0x4
0x1E7B,0x6
0x2154,0x4
0x1D38,0x6
0x2155,0x4
0x1E7C,0x6
0x20B3,0x4
0x1E7D,0x6
0x2156,0x4
0x20B4,0x4
0x1E7E,0x6
0x20B5,0x4
0x2157,0x4
0x1E7F,0x6
0x2158,0x4
0x20B6,0x4
0x2159,0x4
0x20B7,0x4
0x20B8,0x4
0x1E81,0x4
0x20B9,0x4
0x215B,0x4
0x20BA,0x4
0x366,0x4
0x367,0x4
0x368,0x4
0x369,0x4
0x36A,0x4
0x456,0x4
0x457,0x4
0x36B,0x4
0x458,0x4
0x36C,0x4
0x36D,0x4
0x459,0x4
0x45A,0x4
0x36E,0x4
0x45B,0x4
0x36F,0x4
0x45C,0x4
0x21FC,0x4
0x21FD,0x4
0x1E82,0x4
0x1E83,0x4
0x215C,0x4
0x21FE,0x4
0x215D,0x4
0x21FF,0x4
0x1E84,0x4
0x20BC,0x4
0x2200,0x4
0x1E85,0x4
0x215E,0x4
0x215F,0x4
0x1E86,0x4
0x2201,0x4
0x20BD,0x4
0x2160,0x4
0x20BE,0x4
0x2202,0x4
0x1E87,0x4
0x1E88,0x4
0x2161,0x4
0x20BF,0x4
0x2203,0x4
0x2204,0x4
0x1E89,0x4
0x2162,0x4
0x2163,0x4
0x2205,0x4
0x1E8A,0x4
0x20C1,0x4
0x1377,0x6
0x20C2,0x4
0x1E8B,0x4
0x2165,0x4
0x1DEA,0x6
0x20C3,0x4
0x20C4,0x4
0x20C5,0x4
0x1A71,0x6
0x370,0x4
0x371,0x4
0x372,0x4
0x373,0x4
0x374,0x4
0x7DB,0x6
0x375,0x4
0x376,0x4
0x377,0x4
0x378,0x4
0x379,0x4
0x467,0x4
0x468,0x4
0x469,0x4
0x2206,0x4
0x1E8C,0x4
0x2207,0x4
0x2166,0x4
0x2208,0x4
0x1E8D,0x4
0x1E8E,0x4
0x2209,0x4
0x2167,0x4
0x1E8F,0x4
0x2168,0x4
0x20C6,0x4
0x1E90,0x4
0x220B,0x4
0x2169,0x4
0x20C8,0x4
0x220C,0x4
0x216A,0x4
0x1E91,0x4
0x216B,0x4
0x1E92,0x4
0x220D,0x4
0x20C9,0x4
0x220E,0x4
0x1E93,0x4
0x216C,0x4
0x20CA,0x4
0x220F,0x4
0x20CB,0x4
0x216D,0x4
0x1E94,0x4
0x216E,0x4
0x20CC,0x4
0x1E95,0x4
0x20CD,0x4
0x216F,0x4
0x20CE,0x4
0x20CF,0x4
0x37A,0x4
0x37B,0x4
0x37C,0x4
0x37D,0x4
0x46A,0x4
0x37E,0x4
0x46B,0x4
0x37F,0x4
0x46C,0x4
0x380,0x4
0x46D,0x4
0x381,0x4
0x382,0x4
0x46E,0x4
0x383,0x4
0x46F,0x4
0x470,0x4
0x471,0x4
0x472,0x4
0x473,0x4
0x2210,0x4
0x1E96,0x4
0x2211,0x4
0x2212,0x4
0x1E97,0x4
0x2170,0x4
0x1E98,0x4
0x2171,0x4
0x2213,0x4
0x2172,0x4
0x1E99,0x4
0x2214,0x4
0x1A7D,0x6
0x2215,0x4
0x1E9A,0x4
0x2173,0x4
0x2174,0x4
0x1E9B,0x4
0x2216,0x4
0x1E9C,0x4
0x2175,0x4
0x2217,0x4
0x2218,0x4
0x1E9D,0x4
0x2176,0x4
0x2177,0x4
0x1E9E,0x4
0x2219,0x4
0x1E9F,0x4
0x514,0x4
0x515,0x4
0x474,0x4
0x516,0x4
0x517,0x4
0x475,0x4
0x476,0x4
0x518,0x4
0x519,0x4
0x477,0x4
0x51A,0x4
0x478,0x4
0x479,0x4
0x51B,0x4
0x47A,0x4
0x51C,0x4
0x47B,0x4
0x51D,0x4
0x47C,0x4
0x47D,0x4
0x221A,0x4
0x221B,0x4
0x1EA0,0x4
0x221C,0x4
0x1EA1,0x4
0x217A,0x4
0x217B,0x4
0x1EA2,0x4
0x221E,0x4
0x217C,0x4
0x1EA3,0x4
0x1EA4,0x4
0x221F,0x4
0x217D,0x4
0x217E,0x4
0x2220,0x4
0x1EA5,0x4
0x1EA6,0x4
0x217F,0x4
0x2221,0x4
0x1EA7,0x4
0x2180,0x4
0x1EA8,0x4
0x2223,0x4
0x2182,0x4
0x2183,0x4
0x51E,0x4
0x51F,0x4
0x47E,0x4
0x520,0x4
0x521,0x4
0x47F,0x4
0x480,0x4
0x522,0x4
0x523,0x4
0x481,0x4
0x524,0x4
0x482,0x4
0x483,0x4
0x525,0x4
0x526,0x4
0x484,0x4
0x527,0x4
0x485,0x4
0x486,0x4
0x487,0x4
0x2224,0x4
0x1EAA,0x4
0x2225,0x4
0x1EAB,0x4
0x2184,0x4
0x2226,0x4
0x2185,0x4
0x2227,0x4
0x1EAC,0x4
0x1EAD,0x4
0x2228,0x4
0x2229,0x4
0x1EAE,0x4
0x2187,0x4
0x2188,0x4
0x1EAF,0x4
0x222A,0x4
0x1EB0,0x4
0x222B,0x4
0x2189,0x4
0x1EB1,0x4
0x222C,0x4
0x218A,0x4
0x218B,0x4
0x222D,0x4
0x1EB2,0x4
0x218C,0x4
0x1EB3,0x4
0x1E11,0x6
0x218D,0x4
0x528,0x4
0x529,0x4
0x802,0x6
0x488,0x4
0x52A,0x4
0x489,0x4
0x52B,0x4
0x48A,0x4
0x52C,0x4
0x48B,0x4
0x52D,0x4
0x52E,0x4
0x48C,0x4
0x48D,0x4
0x530,0x4
0x48E,0x4
0x531,0x4
0x48F,0x4
0x490,0x4
0x491,0x4
0x222E,0x4
0x1EB4,0x4
0x222F,0x4
0x218E,0x4
0x2230,0x4
0x2231,0x4
0x218F,0x4
0x1EB6,0x4
0x2190,0x4
0x2232,0x4
0x2191,0x4
0x2233,0x4
0x1EB8,0x4
0x2192,0x4
0x1EB9,0x4
0x2234,0x4
0x2193,0x4
0x2235,0x4
0x2236,0x4
0x1EBB,0x4
0x2194,0x4
0x2195,0x4
0x2237,0x4
0x1EBC,0x4
0x1EBD,0x4
0x2196,0x4
0x2197,0x4
0x533,0x4
0x534,0x4
0x492,0x4
0x493,0x4
0x535,0x4
0x494,0x4
0x536,0x4
0x537,0x4
0x495,0x4
0x496,0x4
0x538,0x4
0x497,0x4
0x498,0x4
0x53A,0x4
0x499,0x4
0x53B,0x4
0x49A,0x4
0x49B,0x4
0x2238,0x4
0x2239,0x4
0x1EBE,0x4
0x223A,0x4
0x1EBF,0x4
0x223B,0x4
0x1EC0,0x4
0x1EC1,0x4
0x223C,0x4
0x223D,0x4
0x1EC2,0x4
0x1EC3,0x4
0x223E,0x4
0x1EC4,0x4
0x223F,0x4
0x2240,0x4
0x1EC5,0x4
0x2241,0x4
0x1EC6,0x4
0x1EC7,0x4
0x53C,0x4
0x53D,0x4
0x53E,0x4
0x49C,0x4
0x49D,0x4
0x53F,0x4
0x49E,0x4
0x540,0x4
0x541,0x4
0x542,0x4
0x543,0x4
0x544,0x4
0x545,0x4
0x2242,0x4
0x2243,0x4
0x1EC8,0x4
0x1EC9,0x4
0x2244,0x4
0x1ECA,0x4
0x2245,0x4
0x2246,0x4
0x1ECB,0x4
0x2247,0x4
0x1ECC,0x4
0x2248,0x4
0x1ECD,0x4
0x2249,0x4
0x1ECE,0x4
0x224A,0x4
0x1ECF,0x4
0x224B,0x4
0x1ED0,0x4
0x1ED1,0x4
0xFB5,0x6
0x546,0x4
0x547,0x4
0x4A6,0x4
0x548,0x4
0x4A7,0x4
0x549,0x4
0x4A8,0x4
0x54A,0x4
0x54B,0x4
0x4A9,0x4
0x4AA,0x4
0x54C,0x4
0x4AB,0x4
0x54D,0x4
0x4AC,0x4
0x54E,0x4
0x54F,0x4
0x4AD,0x4
0x4AE,0x4
0x4AF,0x4
0x224C,0x4
0x224D,0x4
0x1ED2,0x4
0x224E,0x4
0x1ED3,0x4
0x1ED4,0x4
0x224F,0x4
0x2250,0x4
0x1ED5,0x4
0x2251,0x4
0x1ED6,0x4
0x1ED7,0x4
0x2252,0x4
0x2253,0x4
0x1ED8,0x4
0x2254,0x4
0x1ED9,0x4
0x1EDA,0x4
0x2255,0x4
0x1EDB,0x4
0x550,0x4
0x551,0x4
0x552,0x4
0x553,0x4
0xFC4,0x6
0x554,0x4
0xC4A,0x6
0x555,0x4
0x556,0x4
0x557,0x4
0x558,0x4
0x559,0x4
0x2256,0x4
0x2257,0x4
0x2258,0x4
0x2259,0x4
0x225A,0x4
0x225B,0x4
0x225C,0x4
0x225D,0x4
0x225E,0x4
0x225F,0x4
0x55A,0x4
0x55B,0x4
0x55C,0x4
0x1070,0x6
0x55E,0x4
0x55F,0x4
0x560,0x4
0x562,0x4
0x563,0x4
0x6C,0x4
0x6D,0x4
0x564,0x4
0x981,0x6
0x565,0x4
0x566,0x4
0x567,0x4
0x568,0x4
0x569,0x4
0x6E,0x4
0x56A,0x4
0x6F,0x4
0x56B,0x4
0x8E6,0x6
0x70,0x4
0x56C,0x4
0x71,0x4
0x56D,0x4
0x72,0x4
0x77,0x6
0x56E,0x4
0x1777,0x6
0x56F,0x4
0x570,0x4
0xD08,0x6
0x571,0x4
0x572,0x4
0x573,0x4
0x78,0x6
0x574,0x4
0x79,0x6
0x575,0x4
0x7A,0x6
0x576,0x4
0x577,0x4
0x7B,0x6
0x7C,0x6
0x7D,0x6
0x7E,0x6
0x7F,0x4
0x80,0x4
0x81,0x4
0x6BD,0x6
0xD14,0x6
0x82,0x4
0x83,0x4
0x84,0x4
0x85,0x4
0x86,0x4
0x87,0x6
0x88,0x6
0x89,0x6
0x8A,0x6
0x8B,0x6
0x1130,0x4
0x1131,0x4
0x1132,0x4
0xDB7,0x6
0x1133,0x4
0x1134,0x4
0x1135,0x4
0x6C4,0x6
0x1136,0x4
0x1137,0x4
0x1138,0x4
0x1139,0x4
0xFF6,0x6
0x62A,0x6
0x8C,0x6
0x8D,0x6
0x8E,0x4
0x8F,0x4
0x90,0x4
0x91,0x4
0x92,0x4
0x95,0x4
0x113A,0x4
0x113B,0x4
0x113C,0x4
0x113D,0x4
0x113E,0x4
0x113F,0x4
0x1140,0x4
0x96,0x4
0x97,0x4
0x98,0x4
0x99,0x6
0x9A,0x6
0x9B,0x6
0x9C,0x6
0x9D,0x6
0x9E,0x6
0x9F,0x6
0xA52,0x6
0xA0,0x6
0xA1,0x6
0xA2,0x6
0xA3,0x6
0xA4,0x6
0xA5,0x6
0xA6,0x6
0xA7,0x6
0xA8,0x4
0xA9,0x4
0xAA,0x4
0xAB,0x4
0xAC,0x4
0xAD,0x4
0xAE,0x4
0xAF,0x6
0xB0,0x6
0xB1,0x6
0xB2,0x6
0xB3,0x6
0x1F40,0x4
0x1F41,0x4
0x1F42,0x4
0x1F43,0x4
0x1F44,0x4
0x1F45,0x4
0x1F46,0x4
0x1F47,0x4
0x1F48,0x4
0x1F49,0x4
0x1F4,0x4
0x1F5,0x4
0x6F1,0x6
0xB4,0x6
0xB5,0x6
0xB6,0x6
0xB7,0x4
0xB8,0x4
0xB9,0x4
0xBA,0x4
0xBB,0x6
0xBC,0x4
0xBD,0x4
0x1F4A,0x4
0x1F4B,0x4
0x1F4C,0x4
0x1F4D,0x4
0x1F4E,0x4
0x1F4F,0x4
0x1F50,0x4
0x1F51,0x4
0x6F5,0x6
0x1F52,0x4
0xDEB,0x6
0x1583,0x6
0x1F53,0x4
0xBE,0x4
0xBF,0x4
0xC0,0x4
0xC1,0x4
0xC2,0x4
0xC3,0x4
